@@ -192,8 +192,10 @@ sub runsmoke_config { # runsmoke.pl
             opt_continue(),
             skip_tests(),
             testmake(),
+            w32args(),
             w32cc(),
             w32make(),
+            pass_option(),
         ],
     );
 }
@@ -420,7 +422,7 @@ sub gitorigin {
     return $opt->new(
         name => 'gitorigin',
         option => '=s',
-        default => 'git://perl5.git.perl.org/perl.git',
+        default => 'git://github.com/Perl/perl5.git',
         helptext => "The remote location of the git repository.",
     );
 }
@@ -700,7 +702,7 @@ sub rsyncsource {
     return $opt->new(
         name => 'source',
         option => '=s',
-        default => 'perl5.git.perl.org::perl-current',
+        default => 'github.com/Perl::perl-current',
         helptext => "The remote location of the rsync archive.",
     );
 }
@@ -897,7 +899,7 @@ sub w32args {
 sub w32cc {
     return $opt->new(
         name => 'w32cc',
-        opt => '=s',
+        option => '=s',
         helptext => "The compiler on MSWin32.",
     );
 }
@@ -905,12 +907,29 @@ sub w32cc {
 sub w32make {
     return $opt->new(
         name => 'w32make',
-        opt => '=s',
+        option => '=s',
         default => 'dmake',
         helptext => "The make program on MSWin32.",
     );
 }
 
+sub pass_option {
+    return $opt->new(
+        name => 'pass_option',
+        option => 'pass-option|p=s@',
+        default => [],
+        allow => sub {
+            my ($list) = @_;
+            return unless ref($list) eq 'ARRAY';
+            for my $to_pass (@$list) {
+                return unless $to_pass =~ m{^ - [DUA] .+ $}x;
+            }
+            return 1;
+        },
+        helptext => 'Pass these options to Configure.',
+    );
+}
+
 1;
 
 =head1 COPYRIGHT
